# TODO
# - update paths in manuals (create .in files and send upstream)
# - make /etc/pam.d independant of sysconfdir (configure-able option and send upstream)
# - syslog output (-s) writes two bytes of garbage to syslog instead of actual data:
#   Mar  3 09:30:01 ravenous CROND[2528]: 4ÿ
#
# Conditional build:
%bcond_without	inotify		# without inotify support
%if "%{pld_release}" == "ac"
%bcond_with		selinux		# with SELinux support
%bcond_with		audit		# with audit support
%else
%bcond_without	selinux		# without SELinux support
%bcond_without	audit		# without audit support
%endif

Summary:	Cron daemon for executing programs at set times
Name:		cronie
Version:	1.5.0
Release:	1
License:	MIT and BSD and GPL v2
Group:		Daemons
Source0:	https://fedorahosted.org/releases/c/r/cronie/%{name}-%{version}.tar.gz
# Source0-md5:	9db75e1884d83a45e002d145c6c54d45
Source1:	%{name}.init
Source2:	cron.logrotate
Source3:	cron.sysconfig
Source4:	%{name}.crontab
Source5:	%{name}.pam
Source6:	crond.service
Patch0:		inotify-nosys.patch
Patch1:		sendmail-path.patch
URL:		https://fedorahosted.org/cronie/
%{?with_audit:BuildRequires:	audit-libs-devel}
BuildRequires:	autoconf
BuildRequires:	automake
%{?with_selinux:BuildRequires:	libselinux-devel}
BuildRequires:	pam-devel
BuildRequires:	rpm >= 4.4.9-56
BuildRequires:	rpmbuild(macros) >= 1.647
Requires(post):	fileutils
Requires(post,preun):	/sbin/chkconfig
Requires(postun):	/usr/sbin/groupdel
Requires(pre):	/usr/bin/getgid
Requires(pre):	/usr/sbin/groupadd
Requires:	/bin/run-parts
Requires:	psmisc >= 20.1
Requires:	rc-scripts >= 0.4.3.0
%if "%{pld_release}" != "ac"
Requires(post,preun,postun):	systemd-units >= 38
Requires:	systemd-units >= 38}
%endif
%{?with_inotify:Requires:	uname(release) >= 2.6.13}
Provides:	crondaemon
Provides:	crontabs = 1.7
Provides:	group(crontab)
%if "%{pld_release}" == "th"
Provides:	vixie-cron = 4.3-1
%endif
Obsoletes:	crondaemon
Obsoletes:	cronie-systemd
Obsoletes:	crontabs
%if "%{pld_release}" == "th"
Obsoletes:	vixie-cron < 4.3-1
%endif
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Cronie contains the standard UNIX daemon crond that runs specified
programs at scheduled times and related tools. It is based on the
original cron and has security and configuration enhancements like the
ability to use pam and SELinux.

%package anacron
Summary:	Utility for running regular jobs
Group:		Base
Provides:	anacron = 2.4
Obsoletes:	anacron <= 2.3

%description anacron
Anacron becames part of cronie. Anacron is used only for running
regular jobs. The default settings execute regular jobs by anacron,
however this could be overloaded in settings.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
%{__aclocal}
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	SYSCRONTAB=/etc/crontab \
	SYS_CROND_DIR=/etc/cron.d \
	--sysconfdir=/etc/cron \
	--with-editor=/bin/vi \
	--with-pam \
	--with%{!?with_selinux:out}-selinux \
	--with%{!?with_audit:out}-audit \
	--with%{!?with_inotify:out}-inotify \
	--disable-syscrontab \
%if "%{cc_version}" >= "3.4"
	--enable-pie \
%endif
	--enable-relro \
	--enable-anacron

%{__make}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{/var/{log,spool/{ana,}cron},%{_mandir},%{systemdunitdir}}\
	$RPM_BUILD_ROOT/etc/{rc.d/init.d,logrotate.d,sysconfig} \
	$RPM_BUILD_ROOT%{_sysconfdir}/{cron,cron.{d,hourly,daily,weekly,monthly},pam.d}

%{__make} install \
	pamdir=/etc/pam.d \
	DESTDIR=$RPM_BUILD_ROOT

cp -p %{SOURCE5} crond.pam

%if %{without audit}
# remove recording user's login uid to the process attribute
%{__sed} -i -e '/pam_loginuid.so/d' crond.pam
%endif

install -p %{SOURCE1} $RPM_BUILD_ROOT/etc/rc.d/init.d/crond
cp -a contrib/0anacron $RPM_BUILD_ROOT/etc/cron.hourly/0anacron
cp -a contrib/anacrontab $RPM_BUILD_ROOT/etc/cron/anacrontab
cp -a %{SOURCE2} $RPM_BUILD_ROOT/etc/logrotate.d/cron
cp -a %{SOURCE3} $RPM_BUILD_ROOT/etc/sysconfig/cron
cp -a %{SOURCE4} $RPM_BUILD_ROOT/etc/cron.d/crontab
cp -a crond.pam  $RPM_BUILD_ROOT/etc/pam.d/crond
cp -a %{SOURCE6} $RPM_BUILD_ROOT%{systemdunitdir}/crond.service

touch $RPM_BUILD_ROOT/var/log/cron

cat > $RPM_BUILD_ROOT%{_sysconfdir}/cron/cron.allow << 'EOF'
# cron.allow	This file describes the names of the users which are
#		allowed to use the local cron daemon
root
EOF

cat > $RPM_BUILD_ROOT%{_sysconfdir}/cron/cron.deny << 'EOF'
# cron.deny	This file describes the names of the users which are
#		NOT allowed to use the local cron daemon
EOF

%clean
rm -rf $RPM_BUILD_ROOT

%pre
%groupadd -g 117 -r -f crontab

%post
if [ ! -f /var/log/cron ]; then
	install -m 660 -g crontab /dev/null /var/log/cron
fi
/sbin/chkconfig --add crond
%service crond restart "Cron Daemon"
%systemd_post crond.service

%preun
if [ "$1" = "0" ]; then
	%service crond stop
	/sbin/chkconfig --del crond
fi
%systemd_preun crond.service

%postun
if [ "$1" = "0" ]; then
	%groupremove crontab
fi
%systemd_reload

%triggerpostun -- cronie < 1.4.8-13
if [ -f /etc/sysconfig/cron ]; then
	. /etc/sysconfig/cron
	__CROND_ARGS=
	[ "$CROND_SYSLOG_RESULT" = "yes" ] && __CROND_ARGS="-s"
	[ -n "$CROND_MAIL_PROG" ] && __CROND_ARGS="$__CROND_ARGS -m $CROND_MAIL_PROG"
	if [ -n "$__CROND_ARGS" ]; then
		%{__cp} -f /etc/sysconfig/cron{,.rpmsave}
		echo >>/etc/sysconfig/cron
		echo "# Added by rpm trigger" >>/etc/sysconfig/cron
		echo "CROND_ARGS=\"$CROND_ARGS $__CROND_ARGS\"" >>/etc/sysconfig/cron
	fi
fi
%systemd_trigger crond.service

%triggerun -- hc-cron,fcron,vixie-cron < 4.3-1
# Prevent preun from crond from working
chmod a-x /etc/rc.d/init.d/crond

%triggerpostun -- hc-cron,fcron,vixie-cron < 4.3-1
# Restore what triggerun removed
chmod 754 /etc/rc.d/init.d/crond
# reinstall crond init.d links, which could be different
/sbin/chkconfig --del crond
/sbin/chkconfig --add crond

%files
%defattr(644,root,root,755)
%doc AUTHORS ChangeLog README
%attr(750,root,crontab) %dir /etc/cron
%attr(750,root,crontab) %dir /etc/cron.daily
%attr(750,root,crontab) %dir /etc/cron.hourly
%attr(750,root,crontab) %dir /etc/cron.monthly
%attr(750,root,crontab) %dir /etc/cron.weekly
%attr(640,root,crontab) %config(noreplace,missingok) /etc/cron.d/crontab
%attr(640,root,crontab) %config(noreplace,missingok) %verify(not md5 mtime size) %{_sysconfdir}/cron/cron.allow
%attr(640,root,crontab) %config(noreplace,missingok) %verify(not md5 mtime size) %{_sysconfdir}/cron/cron.deny
%attr(640,root,root) %config(noreplace) %verify(not md5 mtime size) /etc/sysconfig/cron
%config(noreplace) %verify(not md5 mtime size) /etc/pam.d/crond
%attr(754,root,root) /etc/rc.d/init.d/crond
%attr(640,root,root) %config(noreplace) %verify(not md5 mtime size) /etc/logrotate.d/cron
%{systemdunitdir}/crond.service
%attr(755,root,root) %{_sbindir}/crond
%attr(2755,root,crontab) %{_bindir}/crontab

%{_mandir}/man8/crond.8*
%{_mandir}/man8/cron.8*
%{_mandir}/man5/crontab.5*
%{_mandir}/man1/crontab.1*

%attr(1730,root,crontab) /var/spool/cron
%attr(660,root,crontab) %ghost /var/log/cron

%files anacron
%defattr(644,root,root,755)
%attr(755,root,root) %{_sbindir}/anacron
%attr(755,root,root) %{_sysconfdir}/cron.hourly/0anacron
%attr(640,root,crontab) %config(noreplace,missingok) %verify(not md5 mtime size) /etc/cron/anacrontab
%{_mandir}/man5/anacrontab.5*
%{_mandir}/man8/anacron.8*

%attr(1730,root,crontab) /var/spool/anacron
%changelog
* Fri May 29 2015 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/cronie.git;a=log;h=master

* Fri May 29 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> ced4ed8
- up to 1.5.0

* Thu Apr 23 2015 Jacek Konieczny <j.konieczny@eggsoft.pl> 4b89600
- Drop all Upstart hacks

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> b7b2b1d
- x32 rebuild
- release 4 (by relup.sh)

* Tue Jan 20 2015 Jacek Konieczny <j.konieczny@eggsoft.pl> bbfcd71
- /etc/cron.d is now in the filesystem package

* Wed Dec 10 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> e2d97fc
- rel 2; install anacrontab config

* Thu Sep 18 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> ab5bdbf
- up to 1.4.12

* Thu Nov 21 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 5769fa9
- rel 3; really disable syscrontab

* Fri Sep 20 2013 Elan Ruusamäe <glen@delfi.ee> b4d5e06
- release 2 (by relup.sh)

* Fri Sep 20 2013 Marcin Krol <hawk@tld-linux.org> cf04dab
- use /bin/vi as default editor (1.4.10 changes are forcing
  /usr/bin/vi if EDITOR env var is not defined)

* Fri Jul 19 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> f2d3602
- up to 1.4.11

* Wed Jul 17 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 960d097
- up to 1.4.10

* Tue May 14 2013 Andrzej Zawadzki <zawadaa@pld-linux.org> 5b4e8f0
- add support for recording user's login uid to the process attribute

* Tue Dec 11 2012 Jan Rękorajski <baggins@pld-linux.org> 6f54bc3
- updated to 1.4.9
- removed obsolete patches (nosyscrontab replaced by configure option)

* Tue Dec 11 2012 Jan Rękorajski <baggins@pld-linux.org> dd40ae0
- versioned vixie-cron trigger

* Thu Jun 21 2012 Jan Rękorajski <baggins@pld-linux.org> d4e31b4
- rel 20
- use reload in logrotate config for comaptibility with systemd,
  as flush-logs is just an alias for reload
- fix reload in systemd service

* Tue Apr 17 2012 Jan Rękorajski <baggins@pld-linux.org> 1580d99
- rel 19
- better systemd deps

* Tue Mar 13 2012 Elan Ruusamäe <glen@pld-linux.org> cd63228
- use rpmbuild(macros) that disables systemd stuff for ac

* Mon Mar 12 2012 Elan Ruusamäe <glen@pld-linux.org> 701f459
- clear systemd macros when systemd is off

* Thu Mar 08 2012 Elan Ruusamäe <glen@pld-linux.org> 2bd551b
- skip systemd/upstart for ac

* Thu Mar 08 2012 Elan Ruusamäe <glen@pld-linux.org> a66962a
- -fPIE in gcc 3.4

